@@ -1,8 +1,8 @@
 #!/bin/sh
 
 echo
-echo "No. of vars in global.inc:"
-echo "--------------------------"
+echo "No. of vars in global.inc.php:"
+echo "------------------------------"
 echo -n "non unique:" ; cat global.inc.php | cut -f 1 -d " " | grep "^\\$" | grep -v "^\/" | sort | wc -l
 cat global.inc.php | cut -f 1 -d " " | grep "^\\$" | grep -v "^\/" | sort > non-unique.php
 echo -n "unique:    " ; cat global.inc.php | cut -f 1 -d " " | grep "^\\$" | grep -v "^\/" | sort | uniq | wc -l
