@@ -1,6 +1,6 @@
 <?
-/* (c) 2001 Marco Pratesi (pratesi@telug.it) */
-/* (c) 2000 Fabio Molinari (fabio.m@mclink.it) */
+/* (c) 2001 Marco Pratesi <pratesi@telug.it> */
+/* (c) 2000, 2001 Fabio Molinari <fabio.m@mclink.it> */
 /* with contribution for the script structure 
    from categories.php (c) 2000 Ying Zhang (ying@zippydesign.com) */
 
@@ -21,11 +21,13 @@ switch (nvl($mode)) {
 		break;
 
 	case "edit" :
-		print_edit_iva_form($id);
+		if (!($id == 0))
+			print_edit_iva_form($id);
 		break;
 
 	case "del" :
-		delete_iva($id);
+		if (!($id == 0))
+			delete_iva($id);
 		break;
 
 	case "insert" :
@@ -45,12 +47,13 @@ switch (nvl($mode)) {
 		break;
 
 	case "update" :
+		if ($id == 0)
+			break;
 		$errors = new Object;
 		$errormsg = "";
 		validate_iva($HTTP_POST_VARS["iva"], &$errors, &$errormsg);
 		if (empty($errormsg)) {
 			update_iva($id, $HTTP_POST_VARS);
-			include("templates/iva_updated.ihtml");
 		} else {
 			/* set default values for the reset of the fields */
 			$frm["newmode"] = "update";
@@ -86,7 +89,7 @@ include("templates/footer.ihtml");
  *****************************************************************************/
 
 function print_add_iva_form() {
-/* print a blank iva form so we can add a new iva percentual */
+/* print a blank iva form so we can add a new iva percentage */
 
 	global $CFG, $ME;
 	global $SESSION;
@@ -101,13 +104,13 @@ function print_add_iva_form() {
 }
 
 function print_edit_iva_form($id) {
-/* print an iva form so we can edit the selected iva percentual */
+/* print an iva form so we can edit the selected iva percentage */
 
 	global $CFG, $ME;
 	global $SESSION;
 	include ($CFG->global);
 
-	/* load up the information for the iva percentual */
+	/* load up the information for the iva percentage */
 	$qid = db_query("SELECT iva FROM iva WHERE id = '$id'");
 	$frm = db_fetch_array($qid, 0);
 
@@ -119,8 +122,8 @@ function print_edit_iva_form($id) {
 }
 
 function delete_iva($id) {
-// delete the iva percentual specified by $id, and reset to 0
-// the iva_id for all products with this iva percentual
+// delete the iva percentage specified by $id, and reset to 0
+// the iva_id for all products with this iva percentage
 
 	global $CFG, $ME;
 	global $SESSION;
@@ -128,11 +131,11 @@ function delete_iva($id) {
 
 	$qid = db_begin();
 
-	/* select the iva percentual to be deleted */
+	/* select the iva percentage to be deleted */
 	$qid = db_query("SELECT iva from iva WHERE id = '$id'");
 	$frm = db_fetch_array ($qid, 0);
 
-	/* delete this iva percentual */
+	/* delete this iva percentage */
 	$qid = db_query("DELETE FROM iva WHERE id = '$id'");
 
 	// reset to 1 the iva_id for all products with this iva_id
@@ -146,7 +149,7 @@ function delete_iva($id) {
 }
 
 function insert_iva($frm) {
-/* add a new iva percentual.  all the fields that we want are
+/* add a new iva percentage.  all the fields that we want are
  * going to in the variable $frm */
 
 	global $CFG, $ME;
@@ -167,10 +170,11 @@ function update_iva($id, $frm) {
 	include ($CFG->global);
 
 	$qid = db_query("UPDATE iva SET iva = '$frm[iva]' WHERE id = '$id'");
+	include("templates/iva_updated.ihtml");
 }
 
 function print_iva_list() {
-/* read all the iva percentuals from the database and print them into a table.  we
+/* read all the iva percentages from the database and print them into a table.  we
  * will use a template to display the listings to keep this main script clean */
 
 	global $CFG, $ME;
@@ -207,7 +211,7 @@ function print_iva_list() {
 }
 
 function print_import_iva_form() {
-/* print the import iva form so we can add/update iva percentuals from a text file */
+/* print the import iva form so we can add/update iva percentages from a text file */
 	global $CFG, $ME, $SESSION;
 	include ($CFG->global);
 
@@ -219,7 +223,7 @@ function print_import_iva_form() {
 }
 
 function import_iva($userfile) {
-/* Import iva percentuals from a text file */
+/* Import iva percentages from a text file */
 	global $CFG, $ME, $SESSION;
 	include ($CFG->global);
 	$errors = new Object;
@@ -233,14 +237,10 @@ function import_iva($userfile) {
 		$line = ereg_replace(chr(13), "", $line);
 //		$fldarr = split("\",\"",ereg_replace("^\"|\"..$|\".$","",$line));
 		$fldarr = split("\t",ereg_replace("\n$","",$line));
+		/* dangerous characters quoting */
+		$fldarr[0] = addslashes($fldarr[0]);
 
-		$arr = db_fetch_array($qid,0);
-		$pid = $arr[0];
-
-		/* Stripping dangerous characters from fields */
-		$fldarr[0] = ereg_replace("\'","",$fldarr[0]);
-
-		/* ... and let's see if the iva percentual already exists ... */
+		/* ... and let's see if the iva percentage already exists ... */
 		$qid = db_query("
 		SELECT id FROM iva WHERE iva = '$fldarr[0]'
 		");
