@@ -1,6 +1,6 @@
 <?
-/* (c) 2001 Marco Pratesi (pratesi@telug.it) */
-/* (c) 2000 Fabio Molinari (fabio.m@mclink.it) */
+/* (c) 2001 Marco Pratesi <pratesi@telug.it> */
+/* (c) 2000, 2001 Fabio Molinari <fabio.m@mclink.it> */
 /* with contribution for the script structure 
    from categories.php (c) 2000 Ying Zhang (ying@zippydesign.com) */
 
@@ -21,11 +21,13 @@ switch (nvl($mode)) {
 		break;
 
 	case "edit" :
-		print_edit_order_state_form($id);
+		if (!($id == 0))
+			print_edit_order_state_form($id);
 		break;
 
 	case "del" :
-		delete_order_state($id);
+		if (!($id == 0))
+			delete_order_state($id);
 		break;
 
 	case "insert" :
@@ -47,13 +49,14 @@ switch (nvl($mode)) {
 		break;
 
 	case "update" :
+		if ($id == 0)
+			break;
 		$errors = new Object;
 		$errormsg = "";
 		validate_order_state_name($HTTP_POST_VARS["name"], &$errors, &$errormsg);
 		validate_order_state_description($HTTP_POST_VARS["description"], &$errors, &$errormsg);
 		if (empty($errormsg)) {
 			update_order_state($id, $HTTP_POST_VARS);
-			include("templates/order_state_updated.ihtml");
 		} else {
 			/* set default values for the reset of the fields */
 			$frm["newmode"] = "update";
@@ -201,6 +204,8 @@ function update_order_state($id, $frm) {
 		,description = '$frm[description]'
 	WHERE id = '$id'
 	");
+
+	include("templates/order_state_updated.ihtml");
 }
 
 function print_orders_states_list() {
@@ -216,6 +221,7 @@ function print_orders_states_list() {
 		$qid = db_query("
 		SELECT id, name, description
 		FROM orders_states
+		WHERE id > 0
 		ORDER BY name
 		");
 
@@ -270,15 +276,9 @@ function import_orders_states($userfile) {
 		$line = ereg_replace(chr(13), "", $line);
 //		$fldarr = split("\",\"",ereg_replace("^\"|\"..$|\".$","",$line));
 		$fldarr = split("\t",ereg_replace("\n$","",$line));
-
-//		/* Stripping dangerous characters from fields */
-//		$fldarr[0] = ereg_replace("\'","",$fldarr[0]);
-		$fldarr[0] = ereg_replace("'","\'",$fldarr[0]);
-		$fldarr[0] = ereg_replace("\"","\\\"",$fldarr[0]);
-
-//		$fldarr[1] = ereg_replace("\'","",$fldarr[1]);
-		$fldarr[1] = ereg_replace("'","\'",$fldarr[1]);
-		$fldarr[1] = ereg_replace("\"","\\\"",$fldarr[1]);
+		/* dangerous characters quoting */
+		for ($i=0; $i<2; $i++)
+			$fldarr[$i] = addslashes($fldarr[$i]);
 
 		/* ... and let's see if the state already exists ... */
 		$qid = db_query("
@@ -297,8 +297,7 @@ function import_orders_states($userfile) {
 			/* ... and update ... */
 			$qid = db_query("
 			UPDATE orders_states SET
-				name = '$fldarr[0]'
-				,description = '$fldarr[1]'
+				description = '$fldarr[1]'
 			WHERE id = '$sid'
 			");
 		}
