@@ -12,8 +12,8 @@
  * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
  */
 
-/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */
-/* (c) 2000 Fabio Molinari (fabio.m@mclink.it) */
+/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
+/* (c) 2000, 2001 Fabio Molinari <fabio.m@mclink.it> */
 
 /******************************************************************************
  * MAIN
@@ -76,7 +76,7 @@ switch (nvl($mode)) {
 				$frm["brand_id"] = $HTTP_POST_VARS["brand_id"];
 			}
 			if ($SESSION["iva_used"]) {
-				// load up all the iva percentuals
+				// load up all the iva percentages
 				$qid = db_query("SELECT id, iva FROM iva ORDER BY iva");
 				$frm["iva"] = array();
 				$numr = db_num_rows($qid);
@@ -142,7 +142,7 @@ switch (nvl($mode)) {
 				$frm["brand_id"] = $HTTP_POST_VARS["brand_id"];
 			}
 			if ($SESSION["iva_used"]) {
-				// load up all the iva percentuals
+				// load up all the iva percentages
 				$qid = db_query("SELECT id, iva FROM iva ORDER BY iva");
 				$frm["iva"] = array();
 				$numr = db_num_rows($qid);
@@ -247,7 +247,7 @@ function print_add_product_form($category_id = 1) {
 	}
 
 	if ($SESSION["iva_used"]) {
-		// load up all the iva percentuals
+		// load up all the iva percentages
 		$qid = db_query("SELECT id, iva FROM iva ORDER BY iva");
 		$frm["iva"] = array();
 		$numr = db_num_rows($qid);
@@ -298,7 +298,7 @@ function print_edit_product_form($product_id) {
 	}
 
 	if ($SESSION["iva_used"]) {
-		// load up all the iva percentuals
+		// load up all the iva percentages
 		$qid = db_query("SELECT id, iva FROM iva ORDER BY iva");
 		$frm["iva"] = array();
 		$numr = db_num_rows($qid);
@@ -344,9 +344,9 @@ function print_details_product($product_id) {
 
 	/* load up the information for the product */
 	$qid = db_query("
-	SELECT p.* , b.name AS bname
-	FROM products p JOIN brands b ON (p.brand_id = b.id)
-	WHERE p.id = '$product_id'
+	SELECT p.*, b.name AS bname, i.iva
+	FROM products p, brands b, iva i
+	WHERE p.brand_id = b.id AND p.iva_id = i.id AND p.id = '$product_id'
 	");
 	$frm = db_fetch_array($qid, 0);
 
@@ -364,10 +364,6 @@ function print_details_product($product_id) {
 		$frm["categories"][] = $cat->category_id;
 	}
 
-	/* set values for the form */
-	$frm["newmode"] = "update";
-	$frm["submit_caption"] = $Save_Changes;
-
 	/* build the categories listbox options, preselect the selected item */
 	build_category_tree($category_options, $frm["categories"]);
 
@@ -699,16 +695,22 @@ function print_product_list() {
 
 	if (!isset($page_number) || $dbchanged) {
 		$qid = db_query("
-		SELECT p.id AS product_id, p.name, p.price,
-			p.iva_id, p.discount, p.discqty, p.weight,
-			p.description, p.extended_description,
-			p.imagetype, p.imagewidth, p.imageheight,
-			p.thumbwidth, p.thumbheight,
-			c.name AS category
-		FROM products p, products_categories pc, categories c
-		WHERE p.id = pc.product_id
-		  	AND c.id = pc.category_id
-		ORDER BY c.name
+		SELECT
+			p.id AS product_id
+			,p.name
+			,p.price
+			,p.discount
+			,p.discqty
+			,p.weight
+			,p.imagetype
+			,p.imagewidth
+			,p.imageheight
+			,p.thumbwidth
+			,p.thumbheight
+			,c.name AS category
+			,i.iva
+		FROM products p, products_categories pc, categories c, iva i
+		WHERE p.id = pc.product_id AND c.id = pc.category_id AND p.iva_id = i.id ORDER BY c.name
   		");
 	
 		$SESSION["numr"] = db_num_rows($qid);
@@ -761,8 +763,9 @@ function import_products($HTTP_POST_FILES) {
 		$line = ereg_replace(chr(13), "", $line);
 		$fldarr = split("\t",ereg_replace("\n$","",$line));
 //echo "<b>" . $line_num . "</b>:" . $line . "<br>";
-		/* Stripping dangerous characters from field */
-		$fldarr[0] = ereg_replace("\'","",$fldarr[0]);
+		/* dangerous characters quoting */
+		for ($i=0; $i<13; $i++)
+			$fldarr[$i] = addslashes($fldarr[$i]);
 
 		/* Let's see if the category exists ... */
 		$qid = db_query("
@@ -776,12 +779,6 @@ function import_products($HTTP_POST_FILES) {
 			$arr = db_fetch_array($qid,0);
 			$pid = $arr[0];
 
-			/* Stripping dangerous characters from fields */
-			$fldarr[1] = ereg_replace("\'","",$fldarr[1]);
-//			$fldarr[2] = ereg_replace("\'","",$fldarr[2]);
-			$fldarr[2] = ereg_replace("'","\'",$fldarr[2]);
-			$fldarr[2] = ereg_replace("\"","\\\"",$fldarr[2]);
-			$fldarr[3] = ereg_replace("\'","",$fldarr[3]);
 			if($SESSION["brand_used"]) {
 				if ($fldarr[3] == "") {
 					// brand not defined, set the brand_id to 0
@@ -802,8 +799,6 @@ function import_products($HTTP_POST_FILES) {
 					}
 				}
 			}
-			$fldarr[4] = ereg_replace("\'","",$fldarr[4]);
-			$fldarr[5] = ereg_replace("\'","",$fldarr[5]);
 			if($SESSION["iva_used"]) {
 				if ($fldarr[5] == "") {
 					// iva not defined, set it to 0 (iva_id = 0)
@@ -824,21 +819,10 @@ function import_products($HTTP_POST_FILES) {
 					}
 				}
 			}
-			$fldarr[6] = ereg_replace("\'","",$fldarr[6]);
-			$fldarr[7] = ereg_replace("\'","",$fldarr[7]);
-			$fldarr[8] = ereg_replace("\'","",$fldarr[8]);
-			$fldarr[9] = ereg_replace("\'","",$fldarr[9]);
-			$fldarr[10] = ereg_replace("\'","",$fldarr[10]);
-
-//			$fldarr[11] = ereg_replace("\'","",$fldarr[11]);
-			$fldarr[11] = ereg_replace("'","\'",$fldarr[11]);
-			$fldarr[11] = ereg_replace("\"","\\\"",$fldarr[11]);
-			$fldarr[12] = ereg_replace("'","\'",$fldarr[12]);
-			$fldarr[12] = ereg_replace("\"","\\\"",$fldarr[12]);
 
 			/* ... and let's see if the product already exists ... */
 			$qid = db_query("
-			SELECT id, name FROM products WHERE id = '$fldarr[6]'
+			SELECT id, name FROM products WHERE id = '$fldarr[1]'
 			");
 			if (db_num_rows($qid) == 0) {
 				/* ... if it doesn't exist let's create it in the products table ... */
@@ -1001,7 +985,7 @@ function import_images($HTTP_POST_FILES) {
 					if ($type != $oldtype) {
 						system ("rm -f ".$upload_name_old, $result);
 					}
-// ///
+
 					$qid = db_query("
 					UPDATE products SET
 						 imagetype = '$type'
