@@ -12,7 +12,7 @@
  * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
  */
 
-/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */
+/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
 
 /******************************************************************************
  * MAIN
@@ -34,9 +34,9 @@ function load_special_products(&$qid) {
 	include ($CFG->global);
 
 	$qid = db_query("
-			SELECT p.* , b.name AS bname
-			FROM products p JOIN brands b ON (p.brand_id = b.id)
-			WHERE special_flag = 1
+			SELECT p.*, b.name AS bname, i.iva
+			FROM products p, brands b, iva i
+			WHERE p.brand_id = b.id AND p.iva_id = i.id AND special_flag = 1
 			ORDER BY special_level ASC
 			");
 }
