@@ -12,7 +12,7 @@
  * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
  */
 
-/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */
+/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
 
 class Cart {
 	var $items;		/* array of items */
@@ -121,7 +121,17 @@ class Cart {
 			return;
 		}
 
-		$qid = db_query("SELECT id, price, iva_id, discount, discqty, weight FROM products WHERE id IN ($in_clause)");
+		$qid = db_query("
+				SELECT
+					p.id
+					,p.price
+					,p.discount
+					,p.discqty
+					,p.weight
+					,i.iva
+				FROM products p, iva i
+				WHERE p.iva_id = i.id AND p.id IN ($in_clause)
+				");
 		$numr = db_num_rows($qid);
 		for ($i=0; $i<$numr; $i++) {
 			$product = db_fetch_object($qid, $i);
@@ -131,7 +141,7 @@ class Cart {
 				$this->subtotals[$product->id] = $this->items[$product->id] * $product->price;
 			}
 			if ($SESSION["iva_used"]) {
-				$this->subtotals[$product->id] *= (100 + get_iva($product->iva_id)) / 100;
+				$this->subtotals[$product->id] *= (100 + $product->iva) / 100;
 			}
 			$this->total += $this->subtotals[$product->id];
 			$this->weight += $this->items[$product->id] * $product->weight;
