@@ -236,6 +236,10 @@ function string_cleanup ($string) {
 	$string = str_replace("`", "-grave-", $string);
 	$string = str_replace("'", "-apostrophe-", $string);
 	$string = str_replace("", "-cedilla-", $string);
+	$string = str_replace(",", "-comma-", $string);
+	$string = str_replace(".", "-dot-", $string);
+	$string = str_replace(";", "-dotcomma-", $string);
+	$string = str_replace(":", "-dotdot-", $string);
 
 	return $string;
 
@@ -271,6 +275,10 @@ function string_cleanup_js ($string) {
 	$string = str_replace("`", "grave", $string);
 	$string = str_replace("'", "apostrophe", $string);
 	$string = str_replace("", "cedilla", $string);
+	$string = str_replace(",", "comma", $string);
+	$string = str_replace(".", "dot", $string);
+	$string = str_replace(";", "dotcomma", $string);
+	$string = str_replace(":", "dotdot", $string);
 
 	return $string;
 
