@@ -202,9 +202,9 @@
         }
                
         if ($expand[$cnt]==0)
-            echo "<td><a href=\"".$script.$params."\"><img src=\"".$img_expand."\" border=no></a></td>";
+            echo "<td nowrap><a href=\"".$script.$params."\"><img src=\"".$img_expand."\" border=no></a></td>";
         else
-            echo "<td><a href=\"".$script.$params."\"><img src=\"".$img_collapse."\" border=no></a></td>";
+            echo "<td nowrap><a href=\"".$script.$params."\"><img src=\"".$img_collapse."\" border=no></a></td>";
       }
       else
       {
@@ -221,7 +221,7 @@
       if ($tree[$cnt][2]=="")
           echo "<td nowrap colspan=".($maxlevel-$tree[$cnt][0]).">".$tree[$cnt][1]."</td>";
       else
-          echo "<td nowrap colspan=".($maxlevel-$tree[$cnt][0])."><a href=\"".$tree[$cnt][2]."\" target=\"".$tree[$cnt][3]."\">".$tree[$cnt][1]."</a></td>";
+          echo "<td nowrap colspan=".($maxlevel-$tree[$cnt][0])."><a href=\"".$tree[$cnt][2]."\" title=\"" . $tree[$cnt][1] . "\" target=\"".$tree[$cnt][3]."\"><div class=normal>".$tree[$cnt][1]."</div></a></td>";
           
       /****************************************/
       /* end row                              */
