@@ -181,6 +181,7 @@ $Brand_reset_for_products = "The Brand has been reset for all products of that b
 $IVA_reset_for_products = "The " . $IVA . " percentage has been reset for all products with that " . $IVA . " percentage";
 $Users = "Users";
 $Edit_this_order = "Edit this order";
+$Edit_this_order_state = "Edit this order state";
 $Delete_this_order = "Delete this order";
 $Order = "Order";
 $Orders = "Orders";
@@ -225,7 +226,7 @@ $S_Add_Order_State = "[+S] Add Order State";
 $Import_Orders_States = "Import Orders States";
 $The_Order_State = "The Order State";
 $The_order_state = "The order state";
-$Order_State_reset_for_orders = "The order State has been reset for all orders in the named state";
+$Order_State_reset_for_orders = "The Order State has been reset for all orders in the named state";
 
 ////////////////////////////////////////////////////////////
 // shopping scripts
