@@ -102,7 +102,7 @@ function create_order_ca(&$order, &$emailbody) {
 	$custinfo =
 		  $ordersdb[Customer] . " $order->customer\n"
 		. $ordersdb[Phone]    . " $order->contact\n"
-		. $ordersdb[Address]  . " $order->address" . " $order->number\n"
+		. $ordersdb[Address]  . "\n$order->address" . " $order->number\n"
 		. " $order->city\n" . " $order->country\n" . " $order->zip_code\n";
 
 	/* save order information first */
@@ -182,7 +182,7 @@ function create_order_cc(&$order, $passwordric) {
 	$custinfo =
 		  $ordersdb[Customer] . " $order->customer\n"
 		. $ordersdb[Phone]    . " $order->contact\n"
-		. $ordersdb[Address]  . " $order->address" . " $order->number\n"
+		. $ordersdb[Address]  . "\n$order->address" . " $order->number\n"
 		. " $order->city\n" . " $order->country\n" . " $order->zip_code\n";
 
 	/* save order information first */
